@@ -22,6 +22,7 @@ import json
 
 @click.command()
 @click.option('--verbose', '-v', is_flag=True, help="Verbose output")
+@click.help_option("--help", "-h")
 def process(verbose):
     """
     Shallow clones the template, renames and replaces tokens with argument paramters.
@@ -77,6 +78,10 @@ def process(verbose):
         with open(f, "w") as outputfile:
             outputfile.write(newText)
 
+    os.remove("README.md")
+    if (os.path.isfile('README_APP.md')) :
+        os.rename(r'README_APP.md',r'README.md')
+
 
 if __name__ == "__main__":
     process()
@@ -89,7 +94,7 @@ def create_cdk_json(appName, brand):
     # positional arguments to cdk: <appName> <stage> <domain> <appSourcePath> <brand>
     cdk_json = {
         "app": "npx ts-node ./node_modules/ac-app-dist/bin/ac-app-dist.js "
-               + appName + " $STAGE $DOMAIN web/static " + brand + "standalone "
+               + appName + " $STAGE $DOMAIN client/dist " + brand + "standalone "
     }
 
     # Serializing json
@@ -107,9 +112,12 @@ def prepare_personal_yml(logger, appName, brand):
     shell(logger, 'touch personal.env.yml', raise_error=True)
     logger.info("personal.env.yml has been created at application root. Further modifications to "
                 "domain name can be done from here")
+
     d = {'environment': {
         'personal': {'profile': 'default',
-                     'stage': 'dev', 'domain': appName + '-dev.'+brand+'. %domain%'}}}
+                     'stage': 'dev', 'domain': appName + '-dev.'+brand+'.<add-domain-name-here>',
+                     'CDK_DEPLOY_REGION': 'us-east-1', 'CDK_DEPLOY_ACCOUNT': '<add-aws-account-id-here>',
+                     'api_domain': 'services' + '.<add-domain-name-here>', 'api_stage': 'dev'}}}
     with open('personal.env.yml', 'w') as yaml_file:
         yaml.dump(d, yaml_file, default_flow_style=False)
 
